@@ -24,24 +24,37 @@
 #include <QTimer>
 #include <QCursor>
 #include <QMimeData>
+// 条件编译：QWebEngineContextMenuRequest 只在 Qt6 中存在
+#ifndef USE_QT5
 #include <QWebEngineContextMenuRequest>
+#endif
 #include <QFileDialog>
 #include <QStandardPaths>
+// 条件编译：根据 Qt 版本包含不同的音频设备头文件
+#ifdef USE_QT5
+#include <QAudioDeviceInfo>
+#include <QAudio>
+#else
 #include <QMediaDevices>
 #include <QAudioDevice>
+#endif
 
 #include <dguiapplicationhelper.h>
+#include <DSysInfo>
 
 // 获取字号接口
-#ifdef OS_BUILD_V23
-#define DEEPIN_DAEMON_APPEARANCE_SERVICE "org.deepin.dde.Appearance1"
-#define DEEPIN_DAEMON_APPEARANCE_PATH "/org/deepin/dde/Appearance1"
-#define DEEPIN_DAEMON_APPEARANCE_INTERFACE "org.deepin.dde.Appearance1"
-#else
-#define DEEPIN_DAEMON_APPEARANCE_SERVICE "com.deepin.daemon.Appearance"
-#define DEEPIN_DAEMON_APPEARANCE_PATH "/com/deepin/daemon/Appearance"
-#define DEEPIN_DAEMON_APPEARANCE_INTERFACE "com.deepin.daemon.Appearance"
-#endif
+const QString APPEARANCE_SERVICE_V23 = "org.deepin.dde.Appearance1";
+const QString APPEARANCE_PATH_V23 = "/org/deepin/dde/Appearance1";
+const QString APPEARANCE_INTERFACE_V23 = "org.deepin.dde.Appearance1";
+
+const QString APPEARANCE_SERVICE_V20 = "com.deepin.daemon.Appearance";
+const QString APPEARANCE_PATH_V20 = "/com/deepin/daemon/Appearance";
+const QString APPEARANCE_INTERFACE_V20 = "com.deepin.daemon.Appearance";
+
+inline bool isV20() { return Dtk::Core::DSysInfo::majorVersion() == "20"; }
+const QString DEEPIN_DAEMON_APPEARANCE_SERVICE = isV20() ? APPEARANCE_SERVICE_V20 : APPEARANCE_SERVICE_V23;
+const QString DEEPIN_DAEMON_APPEARANCE_PATH = isV20() ? APPEARANCE_PATH_V20 : APPEARANCE_PATH_V23;
+const QString DEEPIN_DAEMON_APPEARANCE_INTERFACE = isV20() ? APPEARANCE_INTERFACE_V20 : APPEARANCE_INTERFACE_V23;
 
 DGUI_USE_NAMESPACE
 
@@ -125,15 +138,17 @@ void WebEngineHandler::onCallJsResult(const QVariant &result)
  */
 void WebEngineHandler::initFontsInformation()
 {
+    qDebug() << "Initializing fonts information";
     // 初始化字体服务Dus接口
     m_appearanceDBusInterface = new QDBusInterface(DEEPIN_DAEMON_APPEARANCE_SERVICE,
                                                    DEEPIN_DAEMON_APPEARANCE_PATH,
                                                    DEEPIN_DAEMON_APPEARANCE_INTERFACE,
                                                    QDBusConnection::sessionBus());
     if (m_appearanceDBusInterface->isValid()) {
-        qInfo() << "字体服务初始化成功！字体服务： " << DEEPIN_DAEMON_APPEARANCE_SERVICE << " 地址："
-                << DEEPIN_DAEMON_APPEARANCE_PATH << " 接口：" << DEEPIN_DAEMON_APPEARANCE_INTERFACE;
-        // 获取默认字体
+        qInfo() << "Font service initialized successfully. Service:" << DEEPIN_DAEMON_APPEARANCE_SERVICE 
+                << "Path:" << DEEPIN_DAEMON_APPEARANCE_PATH 
+                << "Interface:" << DEEPIN_DAEMON_APPEARANCE_INTERFACE;
+        
         QString defaultfont = m_appearanceDBusInterface->property("StandardFont").value<QString>();
         // 获取字体列表
         QDBusPendingReply<QString> font = m_appearanceDBusInterface->call("List", "standardfont");
@@ -161,14 +176,15 @@ void WebEngineHandler::initFontsInformation()
             }
         }
 
-        qInfo() << "带翻译的默认字体: " << m_defaultFont;
+        qInfo() << "Default font with translation:" << m_defaultFont;
         // sort for display name
         std::sort(m_fontList.begin(), m_fontList.end(), [=](const QString &obj1, const QString &obj2) {
             QCollator qc;
             return qc.compare(obj1, obj2) < 0;
         });
+        qDebug() << "Font list sorted, total fonts:" << m_fontList.size();
     } else {
-        qWarning() << "初始化失败！字体服务 (" << DEEPIN_DAEMON_APPEARANCE_SERVICE << ") 不存在";
+        qWarning() << "Font service initialization failed. Service:" << DEEPIN_DAEMON_APPEARANCE_SERVICE << "not found";
     }
 }
 
@@ -194,29 +210,56 @@ void WebEngineHandler::connectWebContent()
 /*!
  * \brief 处理右键菜单请求 \a request , 完成后抛出 requestShowMenu() 信号
  */
+#ifdef USE_QT5
+void WebEngineHandler::onContextMenuRequested(QObject *request)
+{
+    // 从 QObject* 中安全地获取属性
+    const QPoint pos = request->property("position").toPoint();
+
+    switch (menuType) {
+    case VoiceMenu: {
+        processVoiceMenuRequest(request);
+        break;
+    }
+    case PictureMenu: {
+        // 图片菜单的逻辑很简单，直接弹出
+        Q_EMIT requestShowMenu(menuType, pos);
+        break;
+    }
+    case TxtMenu: {
+        // 文本菜单的状态已由QML处理，这里调用C++是为了处理未来可能的特殊逻辑
+        processTextMenuRequest(request);
+        break;
+    }
+    default:
+        break;
+    }
+}
+#else
 void WebEngineHandler::onContextMenuRequested(QWebEngineContextMenuRequest *request)
 {
     switch (menuType) {
-        case VoiceMenu: {
-            processVoiceMenuRequest(request);
-        } break;
-        case PictureMenu: {
-            Q_EMIT requestShowMenu(menuType, request->position());
-        } break;
-        case TxtMenu: {
-            processTextMenuRequest(request);
-        } break;
-        default:
-            break;
+    case VoiceMenu: {
+        processVoiceMenuRequest(request);
+    } break;
+    case PictureMenu: {
+        Q_EMIT requestShowMenu(menuType, request->position());
+    } break;
+    case TxtMenu: {
+        processTextMenuRequest(request);
+    } break;
+    default:
+        break;
     }
 }
+#endif
 
 /**
    @brief 插入音频文件， \a voicePath 为音频文件路径， \a voiceSize 为音频的长度，单位 ms
  */
 void WebEngineHandler::onInsertVoiceItem(const QString &voicePath, quint64 voiceSize)
 {
-    qWarning() << "insert voice item";
+    qDebug() << "Inserting voice item, path:" << voicePath << "size:" << voiceSize << "ms";
 
     VNVoiceBlock data;
     data.ptrVoice->voiceSize = voiceSize;
@@ -230,7 +273,7 @@ void WebEngineHandler::onInsertVoiceItem(const QString &voicePath, quint64 voice
 
     // 关闭应用时，需要同步插入语音并进行后台更新
     if (OpsStateInterface::instance()->isAppQuit()) {
-        // TODO: 完善同步退出处理
+        qDebug() << "App is quitting, performing synchronous voice insertion";
         callJsSynchronous(QString("insertVoiceItem('%1')").arg(value.toString()));
         return;
     }
@@ -242,6 +285,7 @@ void WebEngineHandler::onInsertVoiceItem(const QString &voicePath, quint64 voice
  */
 void WebEngineHandler::onThemeChanged()
 {
+    qDebug() << "Theme changed, updating UI";
     DGuiApplicationHelper *dAppHelper = DGuiApplicationHelper::instance();
     DPalette dp = dAppHelper->applicationPalette();
     // 获取系统高亮色
@@ -272,8 +316,10 @@ void WebEngineHandler::onMenuClicked(ActionManager::ActionKind kind)
     switch (kind) {
         case ActionManager::VoiceAsSave:
             // 另存语音
-            if (!saveMP3())
+            if (!saveMP3()) {
+                qWarning() << "Failed to save MP3";
                 Q_EMIT requestMessageDialog(VNoteMessageDialogHandler::SaveFailed);
+            }
             break;
         case ActionManager::VoiceToText:
             m_voiceToTextHandler->setAudioToText(m_voiceBlock);
@@ -317,16 +363,31 @@ void WebEngineHandler::onMenuClicked(ActionManager::ActionKind kind)
             savePictureAs();
             break;
         case ActionManager::TxtSpeech: {
-            QList<QAudioDevice> outputDevices = QMediaDevices::audioOutputs();
+#ifdef USE_QT5
+            // Qt5 中使用 QAudioDeviceInfo 检查音频输出设备
+            QList<QAudioDeviceInfo> outputDevices = QAudioDeviceInfo::availableDevices(QAudio::AudioOutput);
             if (outputDevices.isEmpty()) {
+                qWarning() << "No audio output devices available";
                 QString errString = VTextSpeechAndTrManager::instance()->errorString(VTextSpeechAndTrManager::NoOutputDevice);
                 if (!errString.isEmpty()) {
                     Q_EMIT popupToast(errString, VTextSpeechAndTrManager::NoOutputDevice);
                 }
                 break;
             }
+#else
+            QList<QAudioDevice> outputDevices = QMediaDevices::audioOutputs();
+            if (outputDevices.isEmpty()) {
+                qWarning() << "No audio output devices available";
+                QString errString = VTextSpeechAndTrManager::instance()->errorString(VTextSpeechAndTrManager::NoOutputDevice);
+                if (!errString.isEmpty()) {
+                    Q_EMIT popupToast(errString, VTextSpeechAndTrManager::NoOutputDevice);
+                }
+                break;
+            }
+#endif
             auto status = VTextSpeechAndTrManager::instance()->onTextToSpeech();
             if (VTextSpeechAndTrManager::Success != status) {
+                qWarning() << "Text to speech failed with status:" << status;
                 QString errString = VTextSpeechAndTrManager::instance()->errorString(status);
                 if (!errString.isEmpty()) {
                     Q_EMIT popupToast(errString, status);
@@ -368,6 +429,7 @@ void WebEngineHandler::onMenuClicked(ActionManager::ActionKind kind)
  */
 void WebEngineHandler::onPaste(bool isVoice)
 {
+    qDebug() << "Paste operation requested, isVoice:" << isVoice;
     if (isVoice) {
         Q_EMIT triggerWebAction(QWebEnginePage::Paste);
         return;
@@ -382,11 +444,14 @@ void WebEngineHandler::onPaste(bool isVoice)
         for (auto url : mimeData->urls()) {
             paths.push_back(url.path());
         }
+        qDebug() << "Pasting URLs:" << paths;
         JsContent::instance()->insertImages(paths);
     } else if (mimeData->hasImage()) {
+        qDebug() << "Pasting image from clipboard";
         JsContent::instance()->insertImages(qvariant_cast<QImage>(mimeData->imageData()));
     } else {
         // 无图片文件，直接调用web端的粘贴事件
+        qDebug() << "Pasting text content";
         Q_EMIT triggerWebAction(QWebEnginePage::Paste);
     }
 }
@@ -394,6 +459,34 @@ void WebEngineHandler::onPaste(bool isVoice)
 /*!
  * \brief 处理语音菜单请求 \a request
  */
+#ifdef USE_QT5
+void WebEngineHandler::processVoiceMenuRequest(QObject *request)
+{
+    m_voiceBlock.reset(new VNVoiceBlock);
+    MetaDataParser dataParser;
+    // 解析json数据
+    if (!dataParser.parse(menuJson, m_voiceBlock.get())) {
+        return;
+    }
+
+    // 语音文件不存在使用弹出提示
+    if (!QFile(m_voiceBlock->voicePath).exists()) {
+        // 异步操作，防止阻塞前端事件
+        QTimer::singleShot(0, this, [this] {
+            Q_EMIT requestMessageDialog(VNoteMessageDialogHandler::VoicePathNoAvail);
+            // 调用 js 删除删除语音文本
+            Q_EMIT JsContent::instance()->callJsDeleteSelection();
+        });
+        return;
+    }
+
+    // 如果当前有语音处于转换状态就将语音转文字选项置灰 (此逻辑已移至QML onAboutToShow，此处为兜底)
+    ActionManager::instance()->enableAction(ActionManager::VoiceToText, !OpsStateInterface::instance()->isVoice2Text());
+    // 请求界面弹出右键菜单
+    const QPoint pos = request->property("position").toPoint();
+    Q_EMIT requestShowMenu(VoiceMenu, pos);
+}
+#else
 void WebEngineHandler::processVoiceMenuRequest(QWebEngineContextMenuRequest *request)
 {
     m_voiceBlock.reset(new VNVoiceBlock);
@@ -419,19 +512,53 @@ void WebEngineHandler::processVoiceMenuRequest(QWebEngineContextMenuRequest *req
     // 请求界面弹出右键菜单
     Q_EMIT requestShowMenu(VoiceMenu, request->position());
 }
+#endif
 
 /*!
  * \brief 处理文本菜单请求 \a request
  */
+#ifdef USE_QT5
+void WebEngineHandler::processTextMenuRequest(QObject *request)
+{
+    // 此处的逻辑是"兜底"，主要逻辑已由QML实现，以确保在所有情况下状态正确
+    const int intFlags = request->property("editFlags").toInt();
+    auto flags = static_cast<QWebEngineContextMenuData::EditFlags>(intFlags);
+
+    ActionManager::instance()->resetCtxMenu(ActionManager::MenuType::TxtCtxMenu, false); // 重置菜单选项
+
+    ActionManager::instance()->visibleAction(ActionManager::TxtStopreading, false);
+
+    // 设置普通菜单项状态
+    if (flags.testFlag(QWebEngineContextMenuData::CanSelectAll)) {
+        ActionManager::instance()->enableAction(ActionManager::TxtSelectAll, true);
+    }
+    if (flags.testFlag(QWebEngineContextMenuData::CanCopy)) {
+        ActionManager::instance()->enableAction(ActionManager::TxtCopy, true);
+        ActionManager::instance()->enableAction(ActionManager::TxtSpeech, true);
+    }
+    if (flags.testFlag(QWebEngineContextMenuData::CanCut)) {
+        ActionManager::instance()->enableAction(ActionManager::TxtCut, true);
+    }
+    if (flags.testFlag(QWebEngineContextMenuData::CanDelete)) {
+        ActionManager::instance()->enableAction(ActionManager::TxtDelete, true);
+    }
+    if (flags.testFlag(QWebEngineContextMenuData::CanPaste)) {
+        ActionManager::instance()->enableAction(ActionManager::TxtPaste, true);
+        ActionManager::instance()->enableAction(ActionManager::TxtDictation, true);
+    }
+
+    const QPoint pos = request->property("position").toPoint();
+    Q_EMIT requestShowMenu(TxtMenu, pos);
+}
+#else
 void WebEngineHandler::processTextMenuRequest(QWebEngineContextMenuRequest *request)
 {
-    ActionManager::instance()->resetCtxMenu(ActionManager::MenuType::TxtCtxMenu, false);  // 重置菜单选项
+    ActionManager::instance()->resetCtxMenu(ActionManager::MenuType::TxtCtxMenu, false); // 重置菜单选项
 
     // TASK-37707: Disable now
     ActionManager::instance()->visibleAction(ActionManager::TxtStopreading, false);
 
-    // 获取web端编辑标志
-    QWebEngineContextMenuRequest::EditFlags flags = request->editFlags();
+    auto flags = request->editFlags();
 
     // 设置普通菜单项状态
     // 可全选
@@ -441,10 +568,6 @@ void WebEngineHandler::processTextMenuRequest(QWebEngineContextMenuRequest *requ
     // 可复制
     if (flags.testFlag(QWebEngineContextMenuRequest::CanCopy)) {
         ActionManager::instance()->enableAction(ActionManager::TxtCopy, true);
-
-        // if (VTextSpeechAndTrManager::getTransEnable()) {
-        //     ActionManager::instance()->enableAction(ActionManager::TxtTranslate, true);
-        // }
         ActionManager::instance()->enableAction(ActionManager::TxtSpeech, true);
     }
     // 可剪切
@@ -464,6 +587,45 @@ void WebEngineHandler::processTextMenuRequest(QWebEngineContextMenuRequest *requ
     // 请求界面弹出右键菜单
     Q_EMIT requestShowMenu(TxtMenu, request->position());
 }
+#endif
+
+/*!
+ * \brief 处理图片菜单请求
+ */
+#ifdef USE_QT5
+// Qt5 下图片菜单直接由 onContextMenuRequested 发出信号，无需单独的 process 函数
+#else
+void WebEngineHandler::processPictureMenuRequest(QWebEngineContextMenuRequest *request)
+{
+    ActionManager::instance()->resetCtxMenu(ActionManager::MenuType::PictureCtxMenu, true);
+
+    auto flags = request->editFlags();
+
+    // 设置普通菜单项状态
+    // 可全选
+    if (flags.testFlag(QWebEngineContextMenuRequest::CanSelectAll)) {
+        ActionManager::instance()->enableAction(ActionManager::PictureSelectAll, true);
+    }
+    // 可复制
+    if (flags.testFlag(QWebEngineContextMenuRequest::CanCopy)) {
+        ActionManager::instance()->enableAction(ActionManager::PictureCopy, true);
+    }
+    // 可剪切
+    if (flags.testFlag(QWebEngineContextMenuRequest::CanCut)) {
+        ActionManager::instance()->enableAction(ActionManager::PictureCut, true);
+    }
+    // 可删除
+    if (flags.testFlag(QWebEngineContextMenuRequest::CanDelete)) {
+        ActionManager::instance()->enableAction(ActionManager::PictureDelete, true);
+    }
+    // 可粘贴
+    if (flags.testFlag(QWebEngineContextMenuRequest::CanPaste)) {
+        ActionManager::instance()->enableAction(ActionManager::PicturePaste, true);
+    }
+
+    Q_EMIT requestShowMenu(PictureMenu, request->position());
+}
+#endif
 
 /**
    @return 返回当前拷贝数据是否包含录音
@@ -476,16 +638,20 @@ bool WebEngineHandler::isVoicePaste()
 
 bool WebEngineHandler::saveMP3()
 {
-    if (!m_voiceBlock)
+    if (!m_voiceBlock) {
+        qWarning() << "No voice block available for saving";
         return false;
-    QString defaultName =
-        QStandardPaths::writableLocation(QStandardPaths::MusicLocation) + "/" + m_voiceBlock.get()->voiceTitle + ".mp3";
+    }
+    QString defaultName = QStandardPaths::writableLocation(QStandardPaths::MusicLocation) + "/" + m_voiceBlock.get()->voiceTitle + ".mp3";
+    qDebug() << "Saving MP3 with default name:" << defaultName;
     QString fileName = QFileDialog::getSaveFileName(0, tr("save as MP3"), defaultName, "*.mp3");
     if (!fileName.isEmpty()) {
         QFileInfo fileInfo(fileName);
         QDir dir = fileInfo.absoluteDir();
-        if (!dir.exists())
+        if (!dir.exists()) {
+            qWarning() << "Target directory does not exist:" << dir.path();
             return false;
+        }
         QFile tmpFile(m_voiceBlock.get()->voicePath);
         return tmpFile.copy(fileName);
     }
@@ -501,6 +667,7 @@ void WebEngineHandler::savePictureAs()
 QString WebEngineHandler::saveAsFile(const QString &originalPath, QString dirPath, const QString &defalutName)
 {
     // 存储文件夹默认为桌面
+    qDebug() << "Saving file, original path:" << originalPath << "default name:" << defalutName;
     if (dirPath.isEmpty()) {
         dirPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
     }
@@ -512,6 +679,7 @@ QString WebEngineHandler::saveAsFile(const QString &originalPath, QString dirPat
     // 获取需要保存的文件位置，默认路径为用户图片文件夹，默认文件名为原文件名
     QString newPath = QFileDialog::getSaveFileName(0, "", dir, filter);
     if (newPath.isEmpty()) {
+        qDebug() << "Save operation cancelled by user";
         return "";
     }
     // 添加文件后缀
@@ -520,17 +688,15 @@ QString WebEngineHandler::saveAsFile(const QString &originalPath, QString dirPat
     }
 
     QFileInfo info(newPath);
-
     if (!QFileInfo(info.dir().path()).isWritable()) {
-        // 文件夹没有写权限
+        qWarning() << "No write permission for directory:" << info.dir().path();
         emit requestMessageDialog(VNoteMessageDialogHandler::NoPermission);
         return "";
     }
     if (info.exists()) {
         // 文件已存在，删除原文件
         if (!info.isWritable()) {
-            // 文件没有写权限
-            //  VNoteMessageDialog audioOutLimit(VNoteMessageDialog::NoPermission);
+            qWarning() << "No write permission for file:" << newPath;
             emit requestMessageDialog(VNoteMessageDialogHandler::NoPermission);
             return "";
         }
@@ -539,9 +705,10 @@ QString WebEngineHandler::saveAsFile(const QString &originalPath, QString dirPat
 
     // 复制文件
     if (!QFile::copy(originalPath, newPath)) {
+        qCritical() << "File copy failed from:" << originalPath << "to:" << newPath;
         emit requestMessageDialog(VNoteMessageDialogHandler::SaveFailed);
-        qCritical() << "copy failed:" << originalPath << ";" << newPath;
         return "";
     }
+    qInfo() << "File saved successfully to:" << newPath;
     return newPath;
 }
